from prettytable import MARKDOWN, PrettyTable


def print_results(scores: dict):
    """Display final results.

    None values are kept to indicate the absence of a certain tag in either annotation or prediction.
    """
    header = ["tag", "predicted", "matched", "Precision", "Recall", "F1", "Support"]
    results = []
    for tag in sorted(scores, reverse=True):
        prec = None if scores[tag]["P"] is None else round(scores[tag]["P"], 3)
        rec = None if scores[tag]["R"] is None else round(scores[tag]["R"], 3)
        f1 = None if scores[tag]["F1"] is None else round(scores[tag]["F1"], 3)

        results.append(
            [
                tag,
                scores[tag]["predicted"],
                scores[tag]["matched"],
                prec,
                rec,
                f1,
                scores[tag]["Support"],
            ],
        )

    table = PrettyTable()
    table.field_names = header
    table.set_style(MARKDOWN)
    table.add_rows(results)
    print(table)


def print_result_compact(scores: dict):
    header = ["tag", "predicted", "matched", "Precision", "Recall", "F1", "Support"]
    result = [
        [
            "All",
            scores["All"]["predicted"],
            scores["All"]["matched"],
            round(scores["All"]["P"], 3),
            round(scores["All"]["R"], 3),
            round(scores["All"]["F1"], 3),
            scores["All"]["Support"],
        ],
    ]

    table = PrettyTable()
    table.field_names = header
    table.set_style(MARKDOWN)
    table.add_rows(result)
    print(table)
