#!/usr/bin/env python
from pathlib import Path

from setuptools import find_packages, setup


def parse_requirements_line(line):
    """Special case for git requirements"""
    if line.startswith("git+http"):
        assert "@" in line, "Branch should be specified with suffix (ex: @master)"
        assert (
            "#egg=" in line
        ), "Package name should be specified with suffix (ex: #egg=kraken)"
        package_name = line.split("#egg=")[-1]
        return f"{package_name} @ {line}"
    else:
        return line


def parse_requirements():
    path = Path(__file__).parent.resolve() / "requirements.txt"
    assert path.exists(), f"Missing requirements: {path}"
    return list(
        map(parse_requirements_line, map(str.strip, path.read_text().splitlines())),
    )


setup(
    name="nerval",
    version=Path("VERSION").read_text(),
    description="Tool to evaluate NER on noisy text.",
    author="Teklia",
    author_email="contact@teklia.com",
    packages=find_packages(),
    entry_points={"console_scripts": ["nerval=nerval.cli:main"]},
    install_requires=parse_requirements(),
)
